## cdist-type__motd(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__motd - Manage message of the day

## 2. DESCRIPTION

This cdist type allows you to easily setup /etc/motd.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

source
  If supplied, copy this file from the host running cdist to the target. If not supplied, a default message will be placed onto the target.

## 5. EXAMPLES

    # Use cdist defaults
    __motd

    # Supply source file from a different type
    __motd --source "$__type/files/my-motd"

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).